import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:provider/provider.dart';
import 'package:stretchbox/model/stretched_box_state.dart';
import 'package:stretchbox/vm/stretched_box_viewmodel.dart';

import 'custom_stretched_box.dart';

// 上下布局的 Widget
// ignore: must_be_immutable
class ColumnStretchedBoxWidget extends StretchedBoxWidget {
  final bool defaultStretchState;
  final Widget normalChild;
  final Widget expandChild;

  ColumnStretchedBoxWidget(
    this.defaultStretchState,
    this.normalChild,
    this.expandChild, {
    Key key,
  }) : super(
            key: key,
            defaultStretchState: defaultStretchState,
            normalChild: normalChild,
            expandChild: expandChild);

  @override
  Widget buildContentWidget(
      BuildContext context, StretchedBoxViewModel stretchboxViewModel) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        super.buildContentWidget(context, stretchboxViewModel),
        buildUpDownWidget(context, stretchboxViewModel)
      ],
    );
  }

  Widget buildUpDownWidget(
      BuildContext context, StretchedBoxViewModel stretchboxViewModel) {
    return Selector<StretchedBoxViewModel, StretchedBoxState>(
        selector: (context, value) => stretchboxViewModel?.stretchState,
        builder: (BuildContext context, value, Widget child) {
          if (value == StretchedBoxState.normal) {
            return _buildUpDownRotateWidget();
          } else {
            return Transform.rotate(
              angle: 180,
              child: _buildUpDownRotateWidget(),
            );
          }
        });
  }

  Widget _buildUpDownRotateWidget() {
    return GestureDetector(
        onTap: () {
          stretchboxViewModel?.switchStretchMode();
        },
        child: Container(
            height: 30,
            color: Colors.white,
            width: double.infinity,
            alignment: AlignmentDirectional.center,
            child: Image.asset(
              'images/ic_down_expand.png',
              width: 12,
              height: 6,
            )));
  }
}
